==> haskell-yesod-default-1.2.0-365-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-HfTYO6eIgHkKaU8w9fCMWV
key: yesod-default-1.2.0-HfTYO6eIgHkKaU8w9fCMWV
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
author: Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
abi: c1a3f49eb9a090d03488019316b9afc3
exposed: True
exposed-modules:
    Yesod.Default.Ignore
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-HfTYO6eIgHkKaU8w9fCMWV
depends:
    base-4.11.1.0 yesod-core-1.6.6-1q3Xl7pQ0W6BvQ4XoLEAqM
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             yesod-core-1.6.6-1q3Xl7pQ0W6BvQ4XoLEAqM=746f28dcedcddc204012323a2ed9ca70
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-default-1.2.0-369-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-1wZ5zsOX7rv9RR7mZ6RuZS
key: yesod-default-1.2.0-1wZ5zsOX7rv9RR7mZ6RuZS
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
author: Patrick Brisbin
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
abi: 9b375115ad0292066f9ea19f9db30def
exposed: True
exposed-modules:
    Yesod.Default.Ignore
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-1wZ5zsOX7rv9RR7mZ6RuZS
depends:
    base-4.11.1.0 yesod-core-1.6.6-GZQ2TeyibNG7CvzuLyptp5
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             yesod-core-1.6.6-GZQ2TeyibNG7CvzuLyptp5=9b26aec4562683b267e29accb9599396
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
